<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <!-- nécessite la variable $FORMATLOCALE (pour <xsl:template name="subtemplate_LOCLIB">) -->

<!-- accessible de l'extérieur : MODE_INLINE MODE_BLOCK -->

<!-- fait appel à common_ficheblock.xsl -->

    <xsl:template match="*" mode="MODE_BLOCK">
        <xsl:param name="PARAM_CLASS" select=""/>
        <p class="{$PARAM_CLASS}"><xsl:apply-templates select="."/></p>
    </xsl:template>

    <xsl:template match="*" mode="MODE_LISTITEM">
        <xsl:param name="PARAM_CLASS" select=""/>
        <li>
            <p class="{$PARAM_CLASS}"><xsl:apply-templates select="."/></p>
        </li>
    </xsl:template>

    <xsl:template match="*" mode="MODE_INLINE">
        <xsl:param name="PARAM_SEP" select="', '"/>
        <xsl:if test="position() &gt; 1"><xsl:value-of select="$PARAM_SEP"/></xsl:if>
        <xsl:apply-templates select="."/>
    </xsl:template>

    <xsl:template match="*" mode="MODE_CODE">
        <xsl:param name="PARAM_SEP" select="'; '"/>
        <xsl:if test="position() &gt; 1"><xsl:value-of select="$PARAM_SEP"/></xsl:if>
        <xsl:apply-templates select="." mode="submode_CODE"/>
    </xsl:template>

    <xsl:template match="item">
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="item" mode="submode_CODE">
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="personne" mode="submode_CODE">
        <xsl:choose>
            <xsl:when test="@idsphere"><xsl:value-of select="@idsphere"/>[<xsl:value-of select="@sphere"/>]</xsl:when>
            <xsl:otherwise><xsl:apply-templates select="."/></xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="personne[original = true()]">
        <xsl:value-of select="original"/>
        <xsl:if test="(nom = true()) or (prenom=true())">
            <xsl:text> (</xsl:text>
            <xsl:apply-templates select="." mode="submode_PERSONNE"/>
            <xsl:text>)</xsl:text>
        </xsl:if>
        <xsl:if test="string-length(organisme) &gt; 0"><xsl:text> (</xsl:text><xsl:value-of select="organisme"/><xsl:text>)</xsl:text></xsl:if>
    </xsl:template>

    <xsl:template match="personne">
        <xsl:apply-templates select="." mode="submode_PERSONNE"/>
        <xsl:if test="string-length(organisme) &gt; 0"><xsl:text> (</xsl:text><xsl:value-of select="organisme"/><xsl:text>)</xsl:text></xsl:if>
    </xsl:template>

    <xsl:template match="personne[nom/@avant = 'true']" mode="submode_PERSONNE">
        <xsl:value-of select="nom"/><xsl:if test="string-length(prenom) &gt; 0"><xsl:text> </xsl:text><xsl:value-of select="prenom"/></xsl:if>
    </xsl:template>

    <xsl:template match="personne[nom = false()]" mode="submode_PERSONNE">
        <xsl:value-of select="prenom"/>
    </xsl:template>

    <xsl:template match="personne" mode="submode_PERSONNE">
        <xsl:if test="string-length(prenom) &gt; 0"><xsl:value-of select="prenom"/><xsl:text> </xsl:text></xsl:if><xsl:value-of select="nom"/>
    </xsl:template>

    <xsl:template match="entite">
        <xsl:value-of select="nom"/>
        <xsl:if test="string-length(localisation) &gt; 0"><xsl:text>, </xsl:text><xsl:value-of select="localisation"/></xsl:if>
    </xsl:template>

    <xsl:template match="langue">
        <xsl:call-template name="subtemplate_LOCLIB"/>
    </xsl:template>

    <xsl:template match="langue" mode="submode_CODE">
        <xsl:value-of select="@lang"/>
    </xsl:template>

    <xsl:template match="pays">
        <xsl:call-template name="subtemplate_LOCLIB"/>
    </xsl:template>

    <xsl:template match="pays" mode="submode_CODE">
        <xsl:value-of select="@country"/>
    </xsl:template>

    <xsl:template match="image[@base-url]">
        <img src="{@base-url}{@src}" alt="{alt}" title="{lib}"/>
    </xsl:template>

    <xsl:template match="image[@album]">
        <xsl:variable name="var_VignetteSrc">
            <xsl:call-template name="TEMPLATE_ALBUMIMAGEURL">
                <xsl:with-param name="PARAM_ALBUM" select="@album"/>
                <xsl:with-param name="PARAM_DIM" select="@vignette-dim"/>
                <xsl:with-param name="PARAM_IMAGENAME" select="@src"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="var_DetailSrc">
            <xsl:call-template name="TEMPLATE_ALBUMIMAGEURL">
                <xsl:with-param name="PARAM_ALBUM" select="@album"/>
                <xsl:with-param name="PARAM_DIM" select="@detail-dim"/>
                <xsl:with-param name="PARAM_IMAGENAME" select="@src"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="@detail-dim">
                <a href="{$var_DetailSrc}"><img src="{$var_VignetteSrc}" alt="{alt}" title="{lib}"/></a>
            </xsl:when>
            <xsl:otherwise>
                <img src="{$var_VignetteSrc}" alt="{alt}" title="{lib}"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="image">
        <img src="{@src}" alt="{alt}" title="{lib}"/>
    </xsl:template>

    <xsl:template match="langue" mode="submode_CODE">
        <xsl:value-of select="@src"/>
    </xsl:template>

    <xsl:template match="para">
        <xsl:call-template name="subtemplate_PRGCONTENT"/>
    </xsl:template>

    <xsl:template match="para" mode="submode_CODE">
        <xsl:value-of select="."/>
    </xsl:template>


    <xsl:template match="datation">
        <xsl:call-template name="subtemplate_LOCLIB"/>
    </xsl:template>

    <xsl:template match="montant">
        <xsl:call-template name="subtemplate_LOCLIB"/>
    </xsl:template>

    <xsl:template match="nombre">
        <xsl:call-template name="subtemplate_LOCLIB"/>
    </xsl:template>

    <xsl:template match="geopoint">
        <a href="http://stable.toolserver.org/geohack/geohack.php?params={@lat}_N_{@lon}_E">
            <xsl:apply-templates select="latitude"/><xsl:text> &#x00A0; </xsl:text><xsl:apply-templates select="longitude"/>
        </a>
    </xsl:template>

    <xsl:template match="latitude">
        <xsl:call-template name="subtemplate_LOCLIB"/>
    </xsl:template>

    <xsl:template match="longitude">
        <xsl:call-template name="subtemplate_LOCLIB"/>
    </xsl:template>

    <xsl:template match="courriel">
        <a href="mailto:{.}"><xsl:value-of select="."/></a>
    </xsl:template>

    <xsl:template match="link">
        <a href="{@href}"><xsl:value-of select="title"/></a>
        <xsl:if test="string-length(comment) &gt; 0"><xsl:text> (</xsl:text><xsl:value-of select="comment"/>)</xsl:if>
    </xsl:template>

    <xsl:template name="subtemplate_LOCLIB">
        <xsl:variable name="var_LIB" select="string(lib[@xml:lang = $FORMATLOCALE])"/>
        <xsl:choose>
            <xsl:when test="string-length($var_LIB) &gt; 0"><xsl:value-of select="$var_LIB"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="lib[1]"/></xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>